"use strict";
exports.__esModule = true;
exports.MarkMenu = exports.FontStyle = exports.FontSize = exports.FontsFamily = exports.BackButton = exports.ColorButton = exports.MarkButton = exports.useMarkProp = exports.toggleMark = void 0;
var tslib_1 = require("tslib");
var react_bootstrap_1 = require("react-bootstrap");
var slate_1 = require("slate");
var slate_react_1 = require("slate-react");
var component_bootstrap_1 = require("@victorequena22/component-bootstrap");
var FontsFamily_1 = require("./FontsFamily");
var react_1 = tslib_1.__importStar(require("react"));
var BlockUtils_1 = require("./BlockUtils");
var toggleMark = function (editor, format) {
    var isActive = isMarkActive(editor, format);
    if (isActive) {
        slate_1.Editor.removeMark(editor, format);
    }
    else {
        slate_1.Editor.addMark(editor, format, true);
    }
};
exports.toggleMark = toggleMark;
var useMarkProp = function (mark, def) {
    var editor = (0, slate_react_1.useSlate)();
    var marks = slate_1.Editor.marks(editor);
    var is = marks !== null && marks[mark] !== undefined;
    var value = is ? marks[mark] : def;
    var set = (0, react_1.useCallback)(function (value) { return slate_1.Editor.addMark(editor, mark, value); }, [editor, mark]);
    var click = (0, react_1.useCallback)(function () { return slate_1.Editor.addMark(editor, mark, is ? def : value); }, [editor, is, mark, def, value]);
    return [value, set, click];
};
exports.useMarkProp = useMarkProp;
var getFontSize = function (editor) {
    if ((0, BlockUtils_1.isBlockProps)(editor, 'type', 'heading-one'))
        return 26;
    if ((0, BlockUtils_1.isBlockProps)(editor, 'type', 'heading-two'))
        return 22;
    if ((0, BlockUtils_1.isBlockProps)(editor, 'type', 'heading-tre'))
        return 18;
    if ((0, BlockUtils_1.isBlockProps)(editor, 'type', 'heading-for'))
        return 14;
    return 10;
};
var isMarkActive = function (editor, format) {
    var marks = slate_1.Editor.marks(editor);
    return marks ? marks[format] === true : false;
};
var MarkButton = function (_a) {
    var format = _a.format, icon = _a.icon, tip = _a.tip;
    var editor = (0, slate_react_1.useSlate)();
    return (react_1["default"].createElement(component_bootstrap_1.ButtonConfig, { icon: icon, tip: tip, active: isMarkActive(editor, format), action: function () { return (0, exports.toggleMark)(editor, format); } }));
};
exports.MarkButton = MarkButton;
var ColorButton = function (_a) {
    var _b = _a.left, left = _b === void 0 ? 2 : _b, colores = _a.colores;
    var editor = (0, slate_react_1.useSlate)();
    var marks = slate_1.Editor.marks(editor);
    var is = marks !== null && marks.color !== undefined;
    var color = is ? marks.color : '#000000';
    var style = { width: 32, height: 24, margin: '0 0 0 0', padding: '.25rem .5rem .25rem .5rem' };
    return (react_1["default"].createElement(component_bootstrap_1.ButtonColor, { colores: colores, className: "ml-".concat(left), tip: 'COLOR DE TEXTO', style: style, color: color, invert: true, setData: function (color) { return slate_1.Editor.addMark(editor, 'color', color); }, click: function () { return (is ? slate_1.Editor.addMark(editor, 'color', 'currentColor') : slate_1.Editor.addMark(editor, 'color', color)); } },
        react_1["default"].createElement("i", { className: 'fas fa-font' })));
};
exports.ColorButton = ColorButton;
var BackButton = function (_a) {
    var _b = _a.left, left = _b === void 0 ? 2 : _b, colores = _a.colores;
    var editor = (0, slate_react_1.useSlate)();
    var marks = slate_1.Editor.marks(editor);
    var is = marks !== null && marks.backgroundColor !== undefined;
    var color = is ? marks.backgroundColor : '#00000000';
    var style = { width: 32, height: 24, margin: '0 0 0 0', padding: '.25rem .5rem .25rem .5rem' };
    return react_1["default"].createElement(component_bootstrap_1.ButtonColor, { colores: colores, className: "ml-".concat(left), tip: 'RESALTAR TEXTO', style: style, color: color, setData: function (backgroundColor) { return slate_1.Editor.addMark(editor, 'backgroundColor', backgroundColor); }, click: function () {
            return is ? slate_1.Editor.addMark(editor, 'backgroundColor', '#00000000') : slate_1.Editor.addMark(editor, 'backgroundColor', color);
        } },
        react_1["default"].createElement("i", { className: 'fas fa-paint-roller' }));
};
exports.BackButton = BackButton;
var FontsFamily = function () {
    var editor = (0, slate_react_1.useSlate)();
    var marks = slate_1.Editor.marks(editor);
    var is = marks !== null && marks.fontFamily !== undefined;
    var fontFamily = is ? marks.fontFamily : 'Arial';
    var set = function (e) { return slate_1.Editor.addMark(editor, 'fontFamily', e.currentTarget.value); };
    return (react_1["default"].createElement(react_bootstrap_1.FormControl, { "data-tip": 'ESTILO DE FUENTE', style: { fontFamily: fontFamily, height: '24px', borderRadius: '.25rem 0 0 .25rem', padding: '0 0 0 0' }, className: 'form-control-sm', as: 'select', onChange: set, value: fontFamily }, FontsFamily_1.fontsFamily.map(function (c, i) { return (react_1["default"].createElement("option", { style: { fontFamily: c }, key: "fuente".concat(i) }, c)); })));
};
exports.FontsFamily = FontsFamily;
var FontSize = function () {
    var editor = (0, slate_react_1.useSlate)();
    var marks = slate_1.Editor.marks(editor);
    var is = marks !== null && marks.fontSize !== undefined;
    var fontSize = is ? marks.fontSize : getFontSize(editor);
    return (react_1["default"].createElement(component_bootstrap_1.InputNumber, { "data-tip": 'TAMA\u00D1O DE FUENTE', decimal: 0, style: { borderRadius: '0 .25rem .25rem 0', height: 24 }, value: fontSize, setData: function (s) { return slate_1.Editor.addMark(editor, 'fontSize', s); } }));
};
exports.FontSize = FontSize;
var FontStyle = function (_a) {
    var _b = _a.left, left = _b === void 0 ? 2 : _b, _c = _a.width, width = _c === void 0 ? '290px' : _c;
    var s = { height: 24 };
    return (react_1["default"].createElement(react_bootstrap_1.InputGroup, { className: "m-0 p-0 ml-".concat(left), style: tslib_1.__assign(tslib_1.__assign({}, s), { width: width }) },
        react_1["default"].createElement(react_bootstrap_1.InputGroup.Prepend, { style: tslib_1.__assign(tslib_1.__assign({}, s), { width: 'calc(100% - 60px)' }) },
            react_1["default"].createElement(exports.FontsFamily, null)),
        react_1["default"].createElement(react_bootstrap_1.InputGroup.Append, { style: tslib_1.__assign(tslib_1.__assign({}, s), { width: '60px' }) },
            react_1["default"].createElement(exports.FontSize, null))));
};
exports.FontStyle = FontStyle;
var MarkMenu = function (_a) {
    var _b = _a.left, left = _b === void 0 ? 0 : _b;
    return (react_1["default"].createElement(react_bootstrap_1.ButtonGroup, { className: "ml-".concat(left) },
        react_1["default"].createElement(exports.MarkButton, { tip: 'NEGRITAS', format: 'bold', icon: ' fas fa-bold' }),
        react_1["default"].createElement(exports.MarkButton, { tip: 'CURSIVA', format: 'italic', icon: 'fas fa-italic' }),
        react_1["default"].createElement(exports.MarkButton, { tip: 'SUBRRAYADO', format: 'underline', icon: 'fas fa-underline' })));
};
exports.MarkMenu = MarkMenu;
//# sourceMappingURL=MarkProps.js.map